import { RefObject } from 'react';

/**
 * Hook to determine if browser APIs are safely available
 *
 * @returns {boolean} - Returns true if running in the browser, false if on the server
 *
 * @example
 * ```tsx
 * 'use client';
 *
 * import { useIsBrowser } from 'nextjs-app-hooks';
 *
 * export default function MyComponent() {
 *   const isBrowser = useIsBrowser();
 *
 *   useEffect(() => {
 *     if (isBrowser) {
 *       // Safe to use browser APIs like localStorage, window, etc.
 *       localStorage.setItem('visited', 'true');
 *     }
 *   }, [isBrowser]);
 *
 *   return (
 *     <div>
 *       {isBrowser ? 'Browser APIs are available' : 'Running on the server'}
 *     </div>
 *   );
 * }
 * ```
 */
declare function useIsBrowser(): boolean;

/**
 * Hook to detect if the code is running on the server or client
 *
 * @returns {boolean} - Returns true if running on the server, false if running on the client
 *
 * @example
 * ```tsx
 * 'use client';
 *
 * import { useIsServer } from 'nextjs-app-hooks';
 *
 * export default function MyComponent() {
 *   const isServer = useIsServer();
 *
 *   return (
 *     <div>
 *       {isServer ? 'Rendering on server' : 'Rendering on client'}
 *     </div>
 *   );
 * }
 * ```
 */
declare function useIsServer(): boolean;

/**
 * Battery status information
 */
interface BatteryStatus {
    /**
     * Whether the battery is currently charging
     */
    charging: boolean;
    /**
     * Estimated time in seconds until the battery is fully charged
     * Returns Infinity if the battery is discharging
     */
    chargingTime: number;
    /**
     * Estimated time in seconds until the battery is fully discharged
     * Returns Infinity if the battery is charging
     */
    dischargingTime: number;
    /**
     * Current battery level, from 0.0 to 1.0
     */
    level: number;
    /**
     * Whether the device is connected to power
     * This can be true even when charging is false (e.g., battery is full)
     */
    connected: boolean;
}
/**
 * Hook state for battery information
 */
interface BatteryHookState {
    /**
     * Whether the Battery Status API is supported by the browser
     */
    isSupported: boolean;
    /**
     * Whether the battery information is currently loading
     */
    isLoading: boolean;
    /**
     * Any error that occurred while accessing the battery
     */
    error: Error | null;
    /**
     * The current battery status information
     * Will be null if API is not supported, loading, or an error occurred
     */
    battery: BatteryStatus | null;
}
/**
 * A hook to access and monitor the device's battery status
 *
 * @returns {BatteryHookState} The current battery state and status information
 */
declare function useBattery(): BatteryHookState;

/**
 * Hook options for configuring the click outside detection
 */
interface UseClickOutsideOptions {
    /**
     * Whether the hook is enabled - can be used to conditionally enable/disable
     * @default true
     */
    enabled?: boolean;
    /**
     * Additional elements to ignore when detecting clicks outside
     * Useful for linked components (e.g., a button that toggles a dropdown)
     */
    ignoreRefs?: RefObject<HTMLElement>[];
    /**
     * Mouse events to listen for
     * @default ["mousedown"]
     */
    mouseEvents?: Array<"mousedown" | "mouseup" | "click">;
    /**
     * Whether to listen for touch events (for mobile devices)
     * @default true
     */
    listenForTouchEvents?: boolean;
    /**
     * Whether to ignore scrollbar clicks
     * @default true
     */
    ignoreScrollbar?: boolean;
}
/**
 * A hook that detects clicks outside of a specified element
 *
 * @param onClickOutside - Callback function to be called when a click outside is detected
 * @param options - Configuration options for the hook
 * @returns RefObject to be attached to the element we want to detect clicks outside of
 *
 * @example
 * ```tsx
 * const Modal = ({ isOpen, onClose }) => {
 *   const modalRef = useClickOutside(() => {
 *     if (isOpen) onClose();
 *   });
 *
 *   if (!isOpen) return null;
 *
 *   return (
 *     <div className="modal-overlay">
 *       <div ref={modalRef} className="modal-content">
 *         Modal content here
 *       </div>
 *     </div>
 *   );
 * };
 * ```
 */
declare function useClickOutside<T extends HTMLElement = HTMLElement>(onClickOutside: (event: MouseEvent | TouchEvent) => void, options?: UseClickOutsideOptions): RefObject<T | null>;

export { useBattery, useClickOutside, useIsBrowser, useIsServer };
