// src/hooks/useIsBrowser.ts
import { useState, useEffect } from "react";
function useIsBrowser() {
  const [isBrowser, setIsBrowser] = useState(false);
  useEffect(() => {
    setIsBrowser(true);
  }, []);
  return isBrowser;
}

// src/hooks/useIsServer.ts
import { useState as useState2, useEffect as useEffect2 } from "react";
function useIsServer() {
  const [isServer, setIsServer] = useState2(true);
  useEffect2(() => {
    setIsServer(false);
  }, []);
  return isServer;
}

// src/hooks/useBattery.ts
import { useState as useState3, useEffect as useEffect3 } from "react";
function useBattery() {
  const [state, setState] = useState3({
    isSupported: false,
    isLoading: true,
    error: null,
    battery: null
  });
  useEffect3(() => {
    if (!navigator || !("getBattery" in navigator)) {
      setState({
        isSupported: false,
        isLoading: false,
        error: null,
        battery: null
      });
      return;
    }
    let batteryManager = null;
    let isComponentMounted = true;
    const updateBatteryState = (manager) => {
      if (!isComponentMounted) return;
      if (!manager) {
        setState((prev) => ({
          ...prev,
          isLoading: false,
          error: new Error("Could not access battery information"),
          battery: null
        }));
        return;
      }
      setState({
        isSupported: true,
        isLoading: false,
        error: null,
        battery: {
          charging: manager.charging,
          chargingTime: manager.chargingTime,
          dischargingTime: manager.dischargingTime,
          level: manager.level,
          connected: manager.charging || manager.level === 1 && manager.chargingTime === 0
        }
      });
    };
    const setupBatteryListeners = (manager) => {
      if (!manager) return;
      manager.addEventListener(
        "chargingchange",
        () => updateBatteryState(manager)
      );
      manager.addEventListener(
        "chargingtimechange",
        () => updateBatteryState(manager)
      );
      manager.addEventListener(
        "dischargingtimechange",
        () => updateBatteryState(manager)
      );
      manager.addEventListener(
        "levelchange",
        () => updateBatteryState(manager)
      );
      batteryManager = manager;
    };
    const getBatteryInfo = async () => {
      try {
        const manager = await navigator.getBattery();
        if (isComponentMounted) {
          updateBatteryState(manager);
          setupBatteryListeners(manager);
        }
      } catch (error) {
        if (isComponentMounted) {
          setState({
            isSupported: true,
            // API exists but there was an error
            isLoading: false,
            error: error instanceof Error ? error : new Error("Unknown battery error"),
            battery: null
          });
        }
      }
    };
    getBatteryInfo();
    return () => {
      isComponentMounted = false;
      if (batteryManager) {
        batteryManager.removeEventListener(
          "chargingchange",
          updateBatteryState
        );
        batteryManager.removeEventListener(
          "chargingtimechange",
          updateBatteryState
        );
        batteryManager.removeEventListener(
          "dischargingtimechange",
          updateBatteryState
        );
        batteryManager.removeEventListener("levelchange", updateBatteryState);
      }
    };
  }, []);
  return state;
}

// src/hooks/useClickOutside.ts
import { useEffect as useEffect4, useRef, useCallback } from "react";
import { useState as useState4 } from "react";
function useClickOutside(onClickOutside, options = {}) {
  const {
    enabled = true,
    ignoreRefs = [],
    mouseEvents = ["mousedown"],
    listenForTouchEvents = true,
    ignoreScrollbar = true
  } = options;
  const ref = useRef(null);
  const handleClickOutside = useCallback(
    (event) => {
      if (!enabled) return;
      const target = event.target;
      if (ignoreScrollbar && event instanceof MouseEvent) {
        if (event.clientX >= document.documentElement.clientWidth) {
          return;
        }
      }
      if (ref.current && ref.current.contains(target)) {
        return;
      }
      for (const ignoreRef of ignoreRefs) {
        if (ignoreRef.current && ignoreRef.current.contains(target)) {
          return;
        }
      }
      onClickOutside(event);
    },
    [enabled, ignoreRefs, ignoreScrollbar, onClickOutside]
  );
  useEffect4(() => {
    if (!enabled) return;
    mouseEvents.forEach((mouseEvent) => {
      document.addEventListener(
        mouseEvent,
        handleClickOutside
      );
    });
    if (listenForTouchEvents) {
      document.addEventListener(
        "touchstart",
        handleClickOutside
      );
    }
    return () => {
      mouseEvents.forEach((mouseEvent) => {
        document.removeEventListener(
          mouseEvent,
          handleClickOutside
        );
      });
      if (listenForTouchEvents) {
        document.removeEventListener(
          "touchstart",
          handleClickOutside
        );
      }
    };
  }, [enabled, mouseEvents, listenForTouchEvents, handleClickOutside]);
  return ref;
}
export {
  useBattery,
  useClickOutside,
  useIsBrowser,
  useIsServer
};
